function [Centers] = CMeans(Samples, InitialCenters, NormType, Criterion, Value)
// führt C-Means-Clustering durch.
//
// Calling Sequence
//   [Centers] = CMeans(Samples, InitialCenters, NormType, Criterion, Value) 
//
// Parameters
// Samples: Matrix, die die in Cluster einzuteilen Vektoren als Zeilen enthält 
// InitialCenters: Matrix, die anfängliche Cluster-Zentren als Zeilen enthält
// NormType: Norm der Vektoren, is Skalar größer als null, kann %inf sein
// Criterion: Art der Abbruchbedingung, kann 'iterations' oder 'quantization_error' sein
// Value: Anzahl der Iterationen oder maximaler Quantisierungsfehler
// Centers: resultierende Clusterzentren 
//
// Description
// Diese Funktion führt C-Means-Clustering durch. Zu jeder Zeile von Samples
// wird der nächste Nachbar unter den Zeilen von InitialCenters gesucht. Aus 
// dem Mittelwert aller Vektoren, die demselben Clusterzentrum zugeordnet sind,
// ergibt sich das neue Clusterzentrum.
// 
// Der Prozess endet, wenn eine vorgegebene Anzahl von Iterationen 
// durchgeführt wurde oder der Quantisierungsfehler eine vorgegebene 
// Obergrenze nicht überschreitet.
//
// Wenn von Anfang an die Abbruchbedingung erfüllt ist, ist
// Centers == InitialCenters
//
// Examples
// global CLUSTER_PATH;
// Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
// Samples = strtod(Source(:, 1 : 4));
// InitialCenters = SelectRandomly(Samples, 5);
// Centers = CMeans(Samples, InitialCenters, 2, 'iterations', 10)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetNearestNeighbor
//  GetQuantizationError
//  GetDaviesBouldinIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda ;
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// Diese Datei ist nur dazu da, um eine XML-Datei für die Online-Hilfe zu generieren.
endfunction
