function [Neighbors, Distances] = GetNearestNeighbor(Samples, Centers, NormType)
// berechnet zu jedem Beispielvektor den nächsten Nachbarn innerhalb eines Satzes von Clusterzentren.
//
// Calling Sequence
//   [Neighbors, Distances] = GetNearestNeighbor(Samples, Centers, NormType)
//   [Neighbors] = GetNearestNeighbor(Samples, Centers, NormType)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// Centers: Matrix, die Clusterzentren als Zeilen enthält
// NormType: Norm der Vektoren, is Skalar größer als null, kann %inf sein
// Neighbors: Spaltenvektor, enthält zu zu jeder Zeile von Samples den Index des nächsten Nachbarn
// Distances: Matrix, die die Distanzen zwischen Vektoren (Zeilen) und Clusterzentren (Spalten) enthält, optional
//
// Description
// Diese Funktion berechnet zu jedem Beispielvektor den nächsten Nachbarn
// innerhalb eines Satzes von Clusterzentren. 
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  Centers = SelectRandomly(Samples, 5);
//  NearestNeighbors = GetNearestNeighbor(Samples(1 : 5, :), Centers, 2)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetQuantizationError
//  CMeans
//  GetDaviesBouldinIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// Diese Datei ist nur dazu da, um eine XML-Datei für die Online-Hilfe zu generieren.
endfunction
endfunction
