function [QuantizationError] = GetQuantizationError(Samples, Centers, NormType)
// berechnet die Summer der Differenzen zwischen Beispielvektoren und Clusterzentren.
//
// Calling Sequence
//   [QuantizationError] = GetQuantizationError(Samples, Centers, NormType)
//
// Parameters
// Samples: Matrix, deren Zeilen Beispielvektoren sind
// Centers: Matrix, deren Zeilen Clusterzentren sind
// NormType: Norm der Vektoren, is Skalar größer als null, kann %inf sein
// QuantizationError: Summe der Differenzen zwischen Beispielvektoren und Clusterzentren.
//
// Description
// Diese Funktion sucht zu jeder Zeile von Samples den nächsten Nachbar unter
// den Zeilen von Samples und berechnet die Distanz. Die Summe aller Distanzen
// wird berechnet.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  Centers = CMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  QuantizationError = GetQuantizationError(Samples, Centers, 2)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetNearestNeighbor
//  CMeans
//  GetDaviesBouldinIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// Diese Datei ist nur dazu da, eine XML-Datei für die Online-Hilfe zu generieren.
endfunction
