function [Centers] = CMeans(Samples, InitialCenters, NormType, Criterion, Value)
// はc-meansクラスタリングを行う
//
// Calling Sequence
//   [Centers] = CMeans(Samples, InitialCenters, NormType, Criterion, Value)
//
// Parameters
// Samples:クラスタに写像されるベクトルを含む行列で、ベクトルは行である
// InitialCenters:最初のクラスタの中央点を含む行列で、中央点は行である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Criterion:終了の条件の名前で、可能のある価値は「iterations」（回数）又は「quantization_error」（量子化のエラー）である
// Value:回数又は量子化におけるエラーの最大値である
// Centers:最終のクラスタの中央点である
//
// Description
// 本関数はc-meansクラスタリングを行う。Samplesにおける行はInitialClusterCentersに
// おける最も近い行に写像される。クラスタに所属するベクトルにおける平均値を計算してクラスタ
// の中央点を更新する。最大の回数又は量子化のエラーを達するとこの過程は終了する。 
//  
// 終了の条件は最初から満たされると、Centers == InitialCentersである。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  Centers = CMeans(Samples, InitialCenters, 2, 'iterations', 10)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetNearestNeighbor
//  GetQuantizationError
//  GetDaviesBouldinIndex
//
// Authors
//  画留田ハラルド ;
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
