﻿function[DistanceMatrix] = CreateDistanceMatrix(Source, Destination, NormType)
// calculates the distances between vectors.
//
// Calling Sequence
//   [DistanceMatrix] = CreateDistanceMatrix(Source, Destination, NormType)
//
// Parameters
// Source:行列である
// Destination:行列である 
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// DistanceMatrix:行列で、Source（行）とDestination（列）のベクトル間の差を含む
//
// Description
// 本関数はSourceとDestinationにおけるベクトル間の差を計算する。結果は行列である。
// 行はSourceにおけるベクトルに相当して、列はDestinationにおけるベクトルに相当する。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  Centers = SelectRandomly(Samples, 5);
//  Distances = CreateDistanceMatrix(Samples(1 : 5, :), Centers, 2)
//
// See also
//  SelectRandomly
//  GetNearestNeighbor
//  GetQuantizationError
//  CMeans
//  GetDaviesBouldinIndex
//
// Authors
//  画留田ハラルド ; 
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// This file is for *.xml file generation only.
endfunction
