function [DaviesBouldinIndex] = GetDaviesBouldinIndex(Samples, Centers, NormType, CompactnessType)
// はDavies-Bouldinインデクスを計算する
//
// Calling Sequence
//   [DaviesBouldinIndex] = GetDaviesBouldinIndex(Samples, Centers, NormType, CompactnessType)
//
// Parameters
// Samples:行列で、行はクラスタに所属するベクトルである
// Centers: 行列で、行はクラスタの中央点である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// CompactnessType:クラスタに所属するベクトルと中央点間の差の条
//
// Description
// 本関数はDavies-Bouldinインデクスを計算して、クラスタがどのぐらいコンパクトだか、どのぐらいに差別されるか、
// 判断する。値は低いと、クラスタはコンパクトで、離れている。値は高いと、クラスタのオーバーラップがある。クラスタ
// スタの中央点2つ未満だと、Davies-Bouldinインデクスを計算することは不可能である。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  for k = 2 : 5
//   Centers = CMeans(Samples, InitialCenters(1 : n, :), 2, 'iterations', 10);
//   DaviesBouldinIndex = GetDaviesBouldinIndex(Samples, Centers, 2)
//  end;
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetNearestNeighbor
//  GetQuantizationError
//  CMeans
//
// Authors
//  画留田ハラルド ;
// 
// Bibliography
//   David L. Davies and Donald W. Bouldin, 'A cluster separation measure', IEEE Transaction on Pattern Analysis and Machine Intelligence, vol. 1, no. 2, pp. 224 - 227, 1979

// This file is for *.xml file generation only.
endfunction
