function [Neighbors, Distances] = GetNearestNeighbor(Samples, Centers, NormType)
// は最近傍探索を行う
//
// Calling Sequence
//   [Neighbors, Distances] = GetNearestNeighbor(Samples, Centers, NormType)
//   [Neighbors] = GetNearestNeighbor(Samples, Centers, NormType)
//
// Parameters
// Samples:行列で、行はサンプルである
// Centers:行列で、行はクラスタの中央点である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Neighbors:ベクトルで、格サンプルにおける最近点のインデクスを含む
// Distances:サンプルと中央点間の差を含む行列で、オプショナルである
//
// Description
// 本関数はサンプルのベクタに最も近いクラスタの中央点を探索する。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  Centers = SelectRandomly(Samples, 5);
//  NearestNeighbors = GetNearestNeighbor(Samples(1 : 5, :), Centers, 2)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetQuantizationError
//  CMeans
//  GetDaviesBouldinIndex
//
// Authors
//  画留田ハラルド ; 
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// This file is for *.xml file generation only.
endfunction
