﻿function [QuantizationError] = GetQuantizationError(Samples, Centers, NormType)
// はサンプルとクラスタの中央点間の差を計算する
//
// Calling Sequence
//   [QuantizationError] = GetQuantizationError(Samples, Centers, NormType)
//
// Parameters
// Samples:行列で、行はサンプルである
// Centers:行列で、行はクラスタの中央点である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// QuantizationError:サンプルとクラスタの中央点間の差の合計である
//
// Description
// 本関数は各サンプルに最も近いクラスタの中央点を探索して、差を計算する。サンプルと
// 中央点間の差の合計は計算される。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  Centers = CMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  QuantizationError = GetQuantizationError(Samples, Centers, 2)
//
// See also
//  SelectRandomly
//  CreateDistanceMatrix
//  GetNearestNeighbor
//  CMeans
//  GetDaviesBouldinIndex
//
// Authors
// 画留田ハラルド ; 
//
// Bibliography
//   Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// This file is for *.xml file generation only.
endfunction
