function DistanceMatrix = CreateDistanceMatrix(Source, Destination, NormType)
//////////////////////////////////////////////////////////////////////////// 
// CLUSTER - Clustering Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 3 then
 
  error('Wrong number of inputs.');
 
 end;

 // Source must be a matrix.
 
 if (typeof(Source) ~= 'constant') | (ndims(Source) ~= 2)  then
  
  error('Source must be a 2D matrix.');
  
 end;
 
 // Destination must be a matrix.
 
 if (typeof(Destination) ~= 'constant') | (ndims(Destination) ~= 2)  then
  
  error('Destination must be a 2D matrix.');
  
 end;
 
 // Source and Destination must have the same number of columns.
 
 if size(Source, 2) ~= size(Destination, 2) then
  
  error('Source and Destination must have the same number of columns.');
  
 end;
 
 // NormType must be a scalar greater than zero.
 
 if (typeof(NormType) ~= 'constant') | (~isequal(size(NormType), [1 1])) then
 
  error('NormType must be a scalar greater than zero.');
 
 end;
 
 if NormType <= 0 then
  
  error('NormType must be a scalar greater than zero.');
  
 end;
 
 if NumberOfOutputs ~= 1 then 

  error('Wrong number of outputs.');

 end;
 
 // Initializations
 
 NumberOfRows = size(Source, 1);
 
 NumberOfColumns = size(Destination, 1);
 
 DistanceMatrix = zeros(NumberOfRows, NumberOfColumns);
 
 // Main loop. For each row of Destination the vector difference to each row of
 // Source is calculated For each vector difference the norm is calculated and 
 // stored in DistanceMatrix.
 
 for n = 1 : NumberOfColumns
   
  DifferenceVectors = abs(Source - repmat(Destination(n, :), NumberOfRows, 1));
  
  if NormType ~= %inf then
  
   DistanceMatrix(:, n) = ...
   sum(DifferenceVectors .^ NormType, 'c') .^ (1 / NormType);
  
  else
   
   DistanceMatrix(:, n) = max(DifferenceVectors, 'c');
     
  end;

 end;
 
endfunction