function [Neighbors, Distances] = GetNearestNeighbor(Samples, Centers, NormType)
//////////////////////////////////////////////////////////////////////////// 
// CLUSTER - Clustering Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////

 
 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 3 then
 
  error('Wrong number of inputs.');
  
 end;
 
 // Samples must be a matrix.
 
 if (typeof(Samples) ~= 'constant') | (ndims(Samples) ~= 2)  then
  
  error('Samples must be a 2D matrix.');
  
 end;
 
 // Centers must be a matrix.
 
 if (typeof(Centers) ~= 'constant') | (ndims(Centers) ~= 2)  then
  
  error('Centers must be a 2D matrix.');
  
 end;
 
 // Samples and Centers must have the same number of columns.
 
 if size(Samples, 2) ~= size(Centers, 2) then
  
  error('Samples and Centers must have the same number of columns');
  
 end;
 
 // NormType must be a scalar greater than zero.
 
 if (typeof(NormType) ~= 'constant') | (~isequal(size(NormType), [1 1])) then
 
  error('NormType must be a scalar greater than zero.');
 
 end;
 
 if NormType <= 0 then
  
  error('NormType must be a scalar greater than zero.');
  
 end;
 
 if (NumberOfOutputs < 1) | (NumberOfOutputs > 2) then
  
  error('Wrong number of outputs.');
  
 end;
 
 // Initializations
 
 NumberOfSamples = size(Samples, 1);

 Neighbors = zeros(NumberOfSamples, 1);
 
 DistanceMatrix = CreateDistanceMatrix(Samples, Centers, NormType);
 
 // Main loop. For each sample (row of Distances) the nearest neighbor among
 // the samples (column of Distances) is searched.
 
 for n = 1 : NumberOfSamples
  
  Neighbors(n) = find(DistanceMatrix(n, :) == min(DistanceMatrix(n, :)), 1);
  
 end;
 
 // The second output parameter is optional.
 
 if NumberOfOutputs == 2 then
  
  Distances = DistanceMatrix;
  
 end;
 
endfunction