function ListOfSamples = SelectRandomly(Source, NumberOfSelectedSamples)
//////////////////////////////////////////////////////////////////////////// 
// CLUSTER - Clustering Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 2 then
     
  error('Wrong number of input parameters.');
  
 end;
 
 // Source must be a matrix.
 
 if (typeof(Source) ~= 'constant') | (ndims(Source) ~= 2) then
  
  error('Source must be a 2D matrix.');
  
 end;
 
 // Number of samples must be an integer scalar greater than zero and smaller
 // than or equal to the number of rows of Source.
 
 if (typeof(NumberOfSelectedSamples) ~= 'constant') ...
 |  (~isequal(size(NumberOfSelectedSamples), [1 1])) then
 
  error('NumberOfSelectedSamples must be an integer scalar in the ' + ...
        '[1 size(Source, 1)]');
  
 end;
 
 if (NumberOfSelectedSamples <= 0) ...
 |  (NumberOfSelectedSamples > size(Source, 1)) ...
 |  (NumberOfSelectedSamples ~= round(NumberOfSelectedSamples)) then
  
  error('NumberOfSelectedSamples must be an integer scalar in the ' + ...
        'interval [1 size(Source, 1)]');
  
 end;
 
 if NumberOfOutputs ~= 1 then

  error('Wrong number of output parameters.');

 end;
 
 // Initialization
 
 ListOfIndices = zeros(NumberOfSelectedSamples, 1);
 
 NumberOfSamples = size(Source, 1);
 
 // Main loop. A row of Source is selected as a sample. The same row can be se-
 // lected only once.
 
 for n = 1 : NumberOfSelectedSamples
  
  IsFound = %f;
  
  while ~IsFound
   
   SelectedIndex = round(1 + rand() * NumberOfSamples);
   
   if isempty(find(ListOfIndices == SelectedIndex)) then
    
    ListOfIndices(n) = SelectedIndex;
    
    IsFound = %t;
    
   end;
   
  end;
  
 end;
 
 // The output parameter ListOfSamples includes the selected samples as rows.
 ListOfSamples = Source(ListOfIndices, :);

endfunction